pub(crate) fn build_file_appender(
opts: &LoggingOptions,
kind: LogFileKind,
retention: Option<&DirectoryRetention>,
) -> Box<dyn Write + Send>Expand description
Builds the existing hourly appender, optionally wrapped with retention.
pub(crate) fn build_file_appender(
opts: &LoggingOptions,
kind: LogFileKind,
retention: Option<&DirectoryRetention>,
) -> Box<dyn Write + Send>Builds the existing hourly appender, optionally wrapped with retention.